@@ -16,23 +16,26 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "AddFileThread.h"
+#	include "KnownFile.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#	include "types.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "AddFileThread.h"                  // Needed for this Interface's Prototype(s)
-#include "KnownFile.h"                      // Needed for CKnownFile
-#include "otherfunctions.h"                 // Needed for nstrdup
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
-
 struct UnknownFile_Struct
 {
-    char* name;
-    char* directory;
-    CPartFile* owner;
-};
+    char *name;
+    char *directory;
+    CPartFile *owner;
+}
+
+;
 
 wxMutex CAddFileThread::m_lockWaitingForHashList;
 
