@@ -27,7 +27,7 @@
 
 #include "DownloadListCtrl.h"               // Needed for CDownloadListCtrl
 #include "otherfunctions.h"                 // Needed for GetResString
-#include "Preferences.h"                    // Category_Struct
+#include "Preferences.h"                    // CPreferences::GetCategory
 #include "SharedFileList.h"                 // Needed for CSharedFileList
 #include "TransferWnd.h"                    // Needed for CTransferWnd
 #include "xmule.h"                          // Needed for theApp
