@@ -1,54 +1,61 @@
 // This file is a part of the xMule Project.
-//
+// 
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
-//
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
-//
+// 
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
+// 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ClientCredits.h"
+#	include "opcodes.h"
+#include "otherfunctions.h"                 // md4cpy
+#	include "resource.h"
+#	include "SafeFile.h"
+#	include "updownclient.h"
+#	include "wintypes.h"
+#	include "sockets.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
+#	include "NewFunctions.h"
 #endif
 
-#include "ClientCredits.h"                  // Needed for this Interface's Prototype
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
-#include "NewFunctions.h"                   // Needed for MAP
-#include "opcodes.h"                        // Needed for CREDITFILE_VERSION
-#include "otherfunctions.h"                 // Needed for md4cpy
-#include "Preferences.h"                    // Needed for CPreferences
-#include "resource.h"                       // Needed for IDS_ERR_CREDITFILEOLD
-#include "ServerList.h"                     // Needed for CServerList
-#include "sockets.h"                        // Needed for CServerConnect
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+#include <math.h>
+#include <time.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <wx/utils.h>
+#include <wx/file.h>                        // Needed for wxFile
 
-#include "DynPrefs/DynPrefs.h"              // Needed for theApp.dynprefs
+#include "config.h"
 
-#include <cmath>                            // Needed for std::sqrt
-#include <fcntl.h>                          // Needed for open
-
-#if USE_CRYPTO 
+#if !HAVE_CRYPTO
+    #include "CryptoXMpp.h"
+#else
     #include <cryptopp/config.h>
     #include <cryptopp/osrng.h>
     #include <cryptopp/base64.h>
     #include <cryptopp/files.h>
     #include <cryptopp/sha.h>
-    #define	CryptoXMpp	CryptoPP
-#else
-    #include "CryptoXMpp.h"                 // Needed for Crypto++
+    #define CryptoXMpp CryptoPP
 #endif
 
 #ifdef _DEBUG
@@ -61,13 +68,11 @@ static char THIS_FILE[] = __FILE__;
 #define		CLIENTS_MET_FILENAME	"clients.met"
 
 MAP * mcc = NULL;
-CryptoXMpp::RSASSA_PKCS1v15_SHA_Signer* m_pSignkey;
+
 uint32 ldwForIP;
 
 using namespace CryptoXMpp;
 
-extern int newprefs01_opt[];
-
 CClientCredits::CClientCredits(CreditStruct * in_credits)
 {
     m_pCredits = in_credits;
@@ -242,7 +247,13 @@ CClientCreditsList::CClientCreditsList(CPreferences * in_prefs)
 CClientCreditsList::~ CClientCreditsList()
 {
     SaveList();
-    MapData_RemoveAll(mcc);
+
+    MAP * pos = mcc->next;
+    while (pos->Key)
+    {
+        pos = MapData_Remove(mcc, pos);
+    }
+   
     if (m_pSignkey)
     {
         delete m_pSignkey;
@@ -254,49 +265,57 @@ CClientCreditsList::~ CClientCreditsList()
 
 void CClientCreditsList::LoadList()
 {
-    wxString strFileName = m_pAppPrefs->GetAppDir() + wxString(CLIENTS_MET_FILENAME);
-    int loadlist = open(strFileName, O_RDONLY);
-    if (loadlist != - 1)
+    wxString strFileName(theApp.dynprefs->Get<wxString>("app-directory") + wxString(CLIENTS_MET_FILENAME, *wxConvCurrent));
+    wxFile loadlist;
+    
+    if (loadlist.Open(strFileName, wxFile::read))
     {
         uint8 version;
-        (void) read(loadlist, & version, 1);
+        loadlist.Read(&version, 1);
+
         if (version != CREDITFILE_VERSION && version != CREDITFILE_VERSION_29)
         {
             theApp. xmuledlg->AddLogLine(false, GetResString(IDS_ERR_CREDITFILEOLD));
-            (void) close(loadlist);
+            loadlist.Close();
         }
         else
         {
             struct stat loadlistbuf;
-            fstat(loadlist, & loadlistbuf);
-            wxString strBakFileName = m_pAppPrefs->GetAppDir() + wxString(CLIENTS_MET_FILENAME) + ".BAK";
+            fstat(loadlist.fd(), &loadlistbuf);
+            wxString strBakFileName(strFileName + wxT(".BAK"));
             BOOL bCreateBackup = TRUE;
-            int hBakFile = open(strBakFileName, O_RDONLY);
-            if (hBakFile != ( - 1))
+            wxFile hBakFile;
+
+            if (hBakFile.Open(strBakFileName, wxFile::read))
             {
                 struct stat hBakFilebuf;
-                fstat(hBakFile, & hBakFilebuf);
-                if (hBakFilebuf. st_size > loadlistbuf. st_size)
+                fstat(hBakFile.fd(), &hBakFilebuf);
+
+                if (hBakFilebuf.st_size > loadlistbuf.st_size)
                 {
                     bCreateBackup = FALSE;
                 }
-                (void) close(hBakFile);
+
+                hBakFile.Close();
             }
+
             if (bCreateBackup)
             {
-                (void) close(loadlist);
+                loadlist.Close();
+
                 if (!SafeCopyFile(strFileName, strBakFileName))
                 {
                     printf("info: Could not create backup file '%s'\n", strFileName. c_str());
                 }
-                int loadlist = open(strFileName, O_RDONLY);
-                if (loadlist)
+
+                if (loadlist.Open(strFileName, wxFile::read))
                 {
-                    (void) read(loadlist, & version, 1);
+                    loadlist.Read(&version, 1);
                 }
             }
+
             uint32 count;
-            (void) read(loadlist, & count, 4);
+            loadlist.Read(&count, 4);
             // TODO: should be prime number... and 20% larger
             const uint32 dwExpired = time(NULL) - 12960000;
             // today - 150 day
@@ -307,11 +326,11 @@ void CClientCreditsList::LoadList()
                 memset(newcstruct, 0, sizeof(CreditStruct));
                 if (version == CREDITFILE_VERSION_29)
                 {
-                    (void) read(loadlist, newcstruct, sizeof(CreditStruct_29a));
+                    loadlist.Read(newcstruct, sizeof(CreditStruct_29a));
                 }
                 else
                 {
-                    (void) read(loadlist, newcstruct, sizeof(CreditStruct));
+                    loadlist.Read(newcstruct, sizeof(CreditStruct));
                 }
                 if (newcstruct->nLastSeen < dwExpired)
                 {
@@ -322,7 +341,7 @@ void CClientCreditsList::LoadList()
                 CClientCredits * newcredits = new CClientCredits(newcstruct);
                 MapData_Insert(mcc, newcredits, newcredits->GetKey(), 16);
             }
-            (void) close(loadlist);
+            loadlist.Close();
         }
     }
     else
@@ -335,7 +354,7 @@ void CClientCreditsList::SaveList()
 {
     FILE * savelist;
     m_nLastSaved =::GetTickCount();
-    wxString name = m_pAppPrefs->GetAppDir() + wxString(CLIENTS_MET_FILENAME);
+    wxString name(theApp.dynprefs->Get<wxString>("app-directory") + wxString(CLIENTS_MET_FILENAME, *wxConvCurrent));
     savelist = fopen((const char *) name, "w");
     if (savelist)
     {
@@ -392,7 +411,7 @@ CClientCredits * CClientCreditsList::GetCredit(uchar * key)
 
 void CClientCreditsList::Process()
 {
-    if (::GetTickCount() - m_nLastSaved > (13 * 60000))
+    if (::GetTickCount() - m_nLastSaved > 13 * 60000)
     {
         SaveList();
     }
@@ -483,18 +502,17 @@ void CClientCreditsList::InitalizeCrypting()
     memset(m_abyMyPublicKey, 0, 80);
     // not really needed; better for debugging tho
     m_pSignkey = NULL;
-    if (m_pAppPrefs->IsSecureIdentEnabled())
+    if (theApp.dynprefs->Get<bool>("secure-ident") == true)
     {
         bool bCreateNewKey = false;
-        if (theApp.dynprefs->Get<bool>("renew-priv-key"))
+        if (theApp.dynprefs->Get<bool>("renew-priv-key") == true)
         {
-            printf("It's obvious I want to create some type of key...\n");
             bCreateNewKey = true;
         }
         else
         {
             FILE * hKeyFile = NULL;
-            hKeyFile = fopen((const char *)(m_pAppPrefs->GetAppDir() + wxString("cryptkey.dat")), "r");
+            hKeyFile = fopen(static_cast<const char *>(wxString((theApp.dynprefs->Get<wxString>("app-directory") + wxT("cryptkey.dat"))).c_str()), "r");
             if (hKeyFile != NULL)
             {
                 (void) fclose(hKeyFile);
@@ -506,23 +524,33 @@ void CClientCreditsList::InitalizeCrypting()
         }
         if (bCreateNewKey)
         {
-            //printf("Creating new Cryptkey.dat ... %08x %08x\n", time(NULL), (unsigned char) time(NULL));
+            printf("Creating new Cryptkey.dat ... %08x %08x\n", static_cast<unsigned int>(time(NULL)), static_cast<unsigned int>(time(NULL)));
             for (int i = 0 ; i < (unsigned char) time(NULL) ; i++)
             {
                 (void) rand();
             }
             CreateKeyPair();
         }
+        printf("boo\n");
         char erg[500];
         sprintf(erg, "%s/.xMule/%s", getenv("HOME"), "cryptkey.dat");
         FileSource filesource(erg, true, new Base64Decoder);
         m_pSignkey = new RSASSA_PKCS1v15_SHA_Signer(filesource);
         // calculate and store public key
-        RSASSA_PKCS1v15_SHA_Verifier pubkey( * m_pSignkey);
+        RSASSA_PKCS1v15_SHA_Verifier pubkey(*m_pSignkey);
         ArraySink asink(m_abyMyPublicKey, 80);
         pubkey. DEREncode(asink);
         m_nMyPublicKeyLen = asink. TotalPutLength();
         asink. MessageEnd();
+        printf("PublicKey: keylen=%u\n", m_nMyPublicKeyLen);
+        for (int i = 0 ; i < m_nMyPublicKeyLen ; i++)
+        {
+            if ((i >= 12) && (i < 28 || i >= (m_nMyPublicKeyLen - 16)))
+            {
+                printf("%02x ", m_abyMyPublicKey[i]);
+            }
+        }
+        printf("\n");
     }
 }
 
@@ -531,7 +559,7 @@ void CClientCreditsList::CreateKeyPair()
     AutoSeededRandomPool rng;
     InvertibleRSAFunction privkey;
     privkey. Initialize(rng, 384);
-    Base64Encoder privkeysink(new FileSink(CString(m_pAppPrefs->GetAppDir()) + "cryptkey.dat"));
+    Base64Encoder privkeysink(new FileSink(wxString(theApp.dynprefs->Get<wxString>("app-directory") + wxT("cryptkey.dat"))));
     privkey. DEREncode(privkeysink);
     privkeysink. MessageEnd();
 }
@@ -558,9 +586,9 @@ uint8 CClientCreditsList::CreateSignature(CClientCredits * pTarget, uchar * pach
         memcpy(abyBuffer + keylen + 4 + 4, & byChaIPKind, 1);
         ChIpLen += 5;
     }
-    for (unsigned int i = 0; i < sbbSignature.size(); i++)
+    for (unsigned int i = 0 ; i < sbbSignature. size() ; i++)
     {
-        sbbSignature. begin() [i] = 0;
+        sbbSignature.begin() [i] = 0;
     }
     sigkey->SignMessage(rng, abyBuffer, keylen + ChIpLen, sbbSignature. begin());
     if (nMaxSize > sbbSignature. size())
@@ -629,7 +657,7 @@ bool CClientCreditsList::VerifyIdent(CClientCredits * pTarget, uchar * pachSigna
 
 bool CClientCreditsList::CryptoAvailable()
 {
-    return(m_nMyPublicKeyLen > 0 && m_pSignkey != 0 && m_pAppPrefs->IsSecureIdentEnabled());
+    return(m_nMyPublicKeyLen > 0 && m_pSignkey != 0 && theApp.dynprefs->Get<bool>("secure-ident"));
 }
 
 uint32 CClientCredits::GetSecureWaitStartTime(uint32 dwForIP)
