@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,7 +14,7 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,20 +22,27 @@
 #ifndef CLIENTCRED_H
 #define CLIENTCRED_H
 
-#include "types.h"                          // Needed for uchar
-#include "wintypes.h"                       // Needed for BYTE
+#include "types.h"
+#include "MapKey.h"
 
-#include <ctime>                            // Needed for time
-#include <wx/defs.h>                        // Needed for wxUint32
-
-class CPreferences;
-
-/* winemaker: #pragma pack(1) */
-#define		MAXPUBKEYSIZE		80
 
 #define		CRYPT_CIP_REMOTECLIENT	10
 #define		CRYPT_CIP_LOCALCLIENT	20
 #define		CRYPT_CIP_NONECLIENT	30
+#include "config.h"
+#if !HAVE_CRYPTO
+    #include "CryptoXMpp.h"
+#else
+    #include <cryptopp/cryptlib.h>
+    #include <cryptopp/rsa.h>
+    #define CryptoXMpp CryptoPP
+#endif
+
+/* winemaker: #pragma pack(1) */
+//#include <pshpack1.h>
+#define		MAXPUBKEYSIZE		80
+
+class CPreferences;
 
 #pragma pack(1)
 struct CreditStruct_29a{
@@ -60,7 +67,8 @@ struct CreditStruct{
 };
 #pragma pack()
 
-enum EIdentState {
+enum EIdentState
+{
 	IS_NOTAVAILABLE,
 	IS_IDNEEDED,
 	IS_IDENTIFIED,
@@ -119,23 +127,24 @@ public:
 	~CClientCreditsList();
 	
 	// return signature size, 0 = Failed | use sigkey param for debug only
-	uint8 CreateSignature(CClientCredits* pTarget, uchar* pachOutput, uint8 nMaxSize, uint32 ChallengeIP, uint8 byChaIPKind);
+	uint8	CreateSignature(CClientCredits* pTarget, uchar* pachOutput, uint8 nMaxSize, uint32 ChallengeIP, uint8 byChaIPKind);
 					//CryptoXMpp::RSASSA_PKCS1v15_SHA_Signer* sigkey = NULL);
-	bool VerifyIdent(CClientCredits* pTarget, uchar* pachSignature, uint8 nInputSize, uint32 dwForIP, uint8 byChaIPKind);	
+	bool	VerifyIdent(CClientCredits* pTarget, uchar* pachSignature, uint8 nInputSize, uint32 dwForIP, uint8 byChaIPKind);	
 	CClientCredits* GetCredit(uchar* key);
 
-	void Process();
-	uint8 GetPubKeyLen()					{ return m_nMyPublicKeyLen; }
-	BYTE* GetPublicKey()					{ return m_abyMyPublicKey; }
-	bool CryptoAvailable();
+	void	Process();
+	uint8	GetPubKeyLen()					{ return m_nMyPublicKeyLen; }
+	BYTE*	GetPublicKey()					{ return m_abyMyPublicKey; }
+	bool	CryptoAvailable();
 protected:
-	void LoadList();
-	void SaveList();
-	void InitalizeCrypting();
-	void CreateKeyPair();
+	void	LoadList();
+	void	SaveList();
+	void 	InitalizeCrypting();
+    void CreateKeyPair();
 private:
 	CPreferences*	m_pAppPrefs;
-	uint32			m_nLastSaved;	
+	uint32			m_nLastSaved;
+	CryptoXMpp::RSASSA_PKCS1v15_SHA_Signer*		m_pSignkey;
 	BYTE			m_abyMyPublicKey[80];
 	uint8			m_nMyPublicKeyLen;
 };
