@@ -3,44 +3,48 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+
+#include "ClientDetailDialog.h"             // Interface
+
+#include "ClientCredits.h"                  // IS_IDNEEDED
+#include "ClientList.h"
+#	include "KnownFile.h"
+#	include "muuli_wdr.h"
+#	include "otherfunctions.h"
+#	include "server.h"
+#	include "ServerList.h"
+#	include "SharedFileList.h"
+#	include "wintypes.h"
+#	include "xmule.h"
 #endif
 
-#include <arpa/inet.h>                      // Needed for inet_ntoa
+#include "wx/xrc/xmlres.h"
 
-#include "ClientDetailDialog.h"             // Needed for this Interface's Prototype
-
-#include "ClientCredits.h"                  // Needed for CClientCredits::GetCurrentIdentState
-#include "KnownFile.h"                      // Needed for CKnownFile
-#include "muuli_wdr.h"                      // Needed for clientDetails
-#include "otherfunctions.h"                 // Needed for GetTickCount
-#include "resource.h"                       // Needed for IDS_PRIOLOW
-#include "server.h"                         // Needed for CServer
-#include "ServerList.h"                     // Needed for CServerList
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "sockets.h"                        // Needed for CServer
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "xmule.h"                          // Needed for theApp
-
-#include <wx/sizer.h>                       // Needed for wxSizer::Show
-#include <wx/stattext.h>                    // Needed for wxStaticText
+#include <arpa/inet.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <wx/sizer.h>                       // wxSizer
+#include <wx/stattext.h>                    // wxStaticText
 
 #define GetDlgItem(a,b) wxStaticCast(FindWindowById((a)),b)
 #define IsDlgButtonChecked(x) XRCCTRL(*this,#x,wxCheckBox)->GetValue()
@@ -67,12 +71,20 @@ CClientDetailDialog::~CClientDetailDialog()
 {
 }
 
+#if 0
+void CClientDetailDialog::DoDataExchange(CDataExchange *pDX)
+{
+    CDialog::DoDataExchange(pDX);
+}
+
+#endif
+
 void CClientDetailDialog::OnBnClose(wxCommandEvent &evt)
 {
     EndModal(0);
 }
 
-bool CClientDetailDialog::OnInitDialog()
+BOOL CClientDetailDialog::OnInitDialog()
 {
     Localize();
     char buffer[100];
@@ -92,9 +104,11 @@ bool CClientDetailDialog::OnInitDialog()
     switch (m_client->GetClientSoft())
     {
         case SO_UNKNOWN:
+        {
             GetDlgItem(ID_DSOFT, wxStaticText)->SetLabel("?");
             GetDlgItem(ID_DVERSION, wxStaticText)->SetLabel("?");
             break;
+        }
         case SO_EMULE:
         case SO_OLDEMULE:
         case SO_CDONKEY:
@@ -110,7 +124,7 @@ bool CClientDetailDialog::OnInitDialog()
                 strcpy(buffer, "?");
             }
             else if (version != 0x99)
-            {                
+            {
                 if (m_client->GetClientModString().IsEmpty() == false)
                 {
                     sprintf(buffer, "[ %s ]", m_client->GetClientModString() .c_str());
@@ -141,6 +155,7 @@ bool CClientDetailDialog::OnInitDialog()
             break;
     }
     GetDlgItem(ID_DVERSION, wxStaticText)->SetLabel(wxString(buffer, *wxConvCurrent));
+
     sprintf(buffer, "%u (%s)", m_client->GetUserID(), (m_client->HasLowID() ? GetResString(IDS_PRIOLOW) .GetData(): GetResString(IDS_PRIOHIGH) .GetData()));
     GetDlgItem(ID_DID, wxStaticText)->SetLabel(buffer);
     sprintf(buffer, "%s:%i", m_client->GetFullIP(), m_client->GetUserPort());
@@ -167,8 +182,7 @@ bool CClientDetailDialog::OnInitDialog()
     }
     if (m_client->Credits())
     {
-	    char result[33];
-        unsigned char *key;
+	    char result[33];unsigned char *key;
         switch (m_client->Credits()->GetCurrentIdentState(m_client->GetIP()))
         {
         case IS_IDNEEDED:
@@ -244,8 +258,38 @@ bool CClientDetailDialog::OnInitDialog()
     return true;
 }
 
+#if 0
+BEGIN_MESSAGE_MAP(CClientDetailDialog, CDialog)
+END_MESSAGE_MAP()
+#endif
+
 // CClientDetailDialog message handlers
 void CClientDetailDialog::Localize()
 {
+#if 0
+    GetDlgItem(IDC_STATIC30)->SetWindowText(GetResString(IDS_CD_GENERAL));
+    GetDlgItem(IDC_STATIC31)->SetWindowText(GetResString(IDS_CD_UNAME));
+    GetDlgItem(IDC_STATIC32)->SetWindowText(GetResString(IDS_CD_UHASH));
+    GetDlgItem(IDC_STATIC33)->SetWindowText(GetResString(IDS_CD_CSOFT));
+    GetDlgItem(IDC_STATIC34)->SetWindowText(GetResString(IDS_CD_UIP));
+    GetDlgItem(IDC_STATIC35)->SetWindowText(GetResString(IDS_CD_SIP));
+    GetDlgItem(IDC_STATIC36)->SetWindowText(GetResString(IDS_CD_VERSION));
+    GetDlgItem(IDC_STATIC37)->SetWindowText(GetResString(IDS_CD_UID));
+    GetDlgItem(IDC_STATIC38)->SetWindowText(GetResString(IDS_CD_SNAME));
+    GetDlgItem(IDC_STATIC40)->SetWindowText(GetResString(IDS_CD_TRANS));
+    GetDlgItem(IDC_STATIC41)->SetWindowText(GetResString(IDS_CD_CDOWN));
+    GetDlgItem(IDC_STATIC42)->SetWindowText(GetResString(IDS_CD_DOWN));
+    GetDlgItem(IDC_STATIC43)->SetWindowText(GetResString(IDS_CD_ADOWN));
+    GetDlgItem(IDC_STATIC44)->SetWindowText(GetResString(IDS_CD_TDOWN));
+    GetDlgItem(IDC_STATIC45)->SetWindowText(GetResString(IDS_CD_UP));
+    GetDlgItem(IDC_STATIC46)->SetWindowText(GetResString(IDS_CD_AUP));
+    GetDlgItem(IDC_STATIC47)->SetWindowText(GetResString(IDS_CD_TUP));
+    GetDlgItem(IDC_STATIC50)->SetWindowText(GetResString(IDS_CD_SCORES));
+    GetDlgItem(IDC_STATIC51)->SetWindowText(GetResString(IDS_CD_MOD));
+    GetDlgItem(IDC_STATIC52)->SetWindowText(GetResString(IDS_CD_RATING));
+    GetDlgItem(IDC_STATIC53)->SetWindowText(GetResString(IDS_CD_USCORE));
+    GetDlgItem(IDOK)->SetWindowText(GetResString(IDS_FD_CLOSE));
+    SetWindowText(GetResString(IDS_CD_TITLE));
+#endif
 }
 
