@@ -3,48 +3,85 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+// ClientUDPSocket.cpp : implementation file
+//
+
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ClientUDPSocket.h"
+#	include "DownloadQueue.h"
+#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOP
+#	include "opcodes.h"
+#include "packets.h"                        // Packet
+#include "Preferences.h"                    // CPreferences::GetQueueSize
+#	include "SharedFileList.h"
+#	include "UploadQueue.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
+#include "xmuleIPV4Address.h"               // xmuleIPV4Address
 #endif
 
-#include "ClientUDPSocket.h"                // Needed for this Interface's Prototype
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
-#include "DownloadQueue.h"                  // Needed for CDownloadQueue
-#include "NewSockets.h"                     // Needed for NewSocket_SendPacketOPdata
-#include "opcodes.h"                        // Needed for OP_EMULEPROT
-#include "otherfunctions.h"                 // Needed for GetTickCount
-#include "Preferences.h"                    // Needed for CPreferences
-#include "packets.h"                        // Needed for CTag
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "UploadQueue.h"                    // Needed for CUploadQueue
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for wxSocketBase::SetEventHandler
+#include <arpa/inet.h>
+#include <errno.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <wx/socket.h>
 
-#define ID_SOKETTI 7772
+class ClientUDPSocketEvt: public wxEvtHandler
+{
+private:
+	void HandleSocket(wxSocketEvent& event);
+	DECLARE_EVENT_TABLE();
+};
+
+BEGIN_EVENT_TABLE(ClientUDPSocketEvt, wxEvtHandler)
+	EVT_SOCKET(-1, ClientUDPSocketEvt::HandleSocket)
+END_EVENT_TABLE()
+
+void ClientUDPSocketEvt::HandleSocket(wxSocketEvent& event)
+{
+    CClientUDPSocket* soc = dynamic_cast<CClientUDPSocket *>(event.GetSocket());
+    int id = event.GetSocketEvent();
+
+    if (id == wxSOCKET_INPUT)
+    {
+        if (theApp.dynprefs->Get<bool>("enable-serverless") == false)
+        {
+            soc->OnReceive(0);
+        }
+    }
+    else if (id == wxSOCKET_OUTPUT)
+    {
+        soc->OnSend(0);
+    }
+}
 
 IMPLEMENT_DYNAMIC_CLASS(CClientUDPSocket, wxDatagramSocket)
-CClientUDPSocket::CClientUDPSocket(wxIPV4address address)
-: wxDatagramSocket(address, wxSOCKET_NOWAIT)
+
+CClientUDPSocket::CClientUDPSocket(wxIPV4address address): wxDatagramSocket(address, wxSOCKET_NOWAIT)
 {
     m_bWouldBlock = false;
-    SetEventHandler( *theApp.xmuledlg, ID_SOKETTI);
+    m_event_handler = new ClientUDPSocketEvt;
+    SetEventHandler(*m_event_handler, -1);
     SetNotify(wxSOCKET_INPUT_FLAG |wxSOCKET_OUTPUT_FLAG);
     Notify(TRUE);
 }
@@ -53,6 +90,7 @@ CClientUDPSocket::~CClientUDPSocket()
 {
     SetNotify(0);
     Notify(FALSE);
+    delete m_event_handler;
 }
 
 void CClientUDPSocket::OnReceive(int nErrorCode)
@@ -60,11 +98,13 @@ void CClientUDPSocket::OnReceive(int nErrorCode)
     unsigned char buffer[5000];
     wxIPV4address addr;
     RecvFrom(addr, buffer, 5000);
-    wxInt32 length = LastCount();
+    int32_t length = LastCount();
     wxUint32 fromIP = GAddress_INET_GetHostAddress(addr.GetAddress());
-    if (buffer[0] == OP_EMULEPROT)
-        if (length != -1)
-            ProcessPacket(buffer + 2, length - 2, buffer[1], fromIP, addr.Service());
+
+    if ((buffer[0] == static_cast<unsigned int>(OP_EMULEPROT)) && (length != 0))
+    {
+        ProcessPacket(buffer + 2, length - 2, buffer[1], fromIP, addr.Service());
+    }
 }
 
 bool CClientUDPSocket::ProcessPacket(unsigned char *packet, int16 size, wxUint8 opcode, wxUint32 hostip, uint16 port)
@@ -191,19 +231,21 @@ bool CClientUDPSocket::SendTo(char *lpBuf, int nBufLen, uint32 dwIP, uint16 nPor
 {
     if (Ok())
     {
-        wxIPV4address *addr = new wxIPV4address();
-        (void) GAddress_INET_SetPort(addr->GetAddress(), nPort);
-        (void) GAddress_INET_SetHostAddress(addr->GetAddress(), dwIP);
+        xmuleIPV4Address addr;
+        struct in_addr tmpa;
+        tmpa.s_addr = dwIP;
+        addr.Hostname(tmpa. s_addr);
+        addr.Service(nPort);
 #if defined(__DEBUG__)
         //printf("CClientUDPSocket::SendTo %s:%d\n", (const char *) addr->IPAddress(), addr->Service());
 #endif
-        wxDatagramSocket::SendTo( *addr, lpBuf, nBufLen);
-        delete addr;
+        wxDatagramSocket::SendTo(addr, lpBuf, nBufLen);
     }
     else
     {
         return false;
     }
+
     if (Error())
     {
         uint32 error = LastError();
