@@ -4,47 +4,48 @@
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // parts of this file are based on work from pan One (http://home-3.tiscali.nl/~meost/pms/)
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "ini2.h"
+#	include "KnownFile.h"
+#	include "KnownFileList.h"
+#	include "opcodes.h"
+#	include "otherfunctions.h"
+#include "packets.h"                        // Packet
+#include "PartFile.h"                       // PR_HIGH
+#	include "SharedFileList.h"
+#	include "SharedFilesWnd.h"
+#	include "updownclient.h"
+#	include "UploadQueue.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include <sys/stat.h>                       // Needed for stat
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
-#include "KnownFile.h"                      // Needed for this Interface's Prototype
+#include <sys/types.h>
+#include <sys/stat.h>
 
-#include "BarShader.h"                      // Needed for CBarShader
-#include "CMemFile.h"                       // Needed for CMemFile
-#include "ini2.h"                           // Needed for CIni
-#include "KnownFileList.h"                  // Needed for CKnownFileList
-#include "otherfunctions.h"                 // Needed for nstrdup
-#include "packets.h"                        // Needed for CTag
-#include "PartFile.h"                       // Needed for PR_HIGH
-#include "Preferences.h"                    // Needed for CPreferences
-#include "SharedFileList.h"                 // Needed for UpdateItem
-#include "SharedFilesCtrl.h"                // Needed for CSharedFilesCtrl
-#include "SharedFilesWnd.h"                 // Needed for CSharedFilesWnd
-#include "updownclient.h"                   // Needed for IsUpPartAvailable
-#include "UploadQueue.h"                    // Needed for FindSourcesForFileById
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for CxmuleDlg
+//extern MAP * listof_sourcesKF;
 
-// constants for MD42Transform
+// constants for MD4Transform
 #define S11 3
 #define S12 7
 #define S13 11
@@ -58,7 +59,7 @@
 #define S33 11
 #define S34 15
 
-static void MD42Transform(uint32 Hash[4], uint32 x[16]);
+static void MD4Transform(uint32 Hash[4], uint32 x[16]);
 
 void CFileStatistic::AddRequest()
 {
@@ -93,7 +94,7 @@ CKnownFile::CKnownFile()
     date = 0;
     m_iPermissions = PERM_ALL;
     statistic.fileParent = this;
-    if (theApp.glob_prefs->GetNewAutoUp())
+    if (theApp.dynprefs->Get<bool>("auto-priority-share") == true)
     {
         m_iUpPriority = PR_HIGH;
         m_bAutoUpPriority = true;
@@ -126,7 +127,7 @@ CKnownFile::~CKnownFile()
 
 CBarShader CKnownFile::s_ShareStatusBar(16);
 
-void CKnownFile::DrawShareStatusBar(wxDC* dc, wxRect rect, bool onlygreyrect, bool bFlat)
+void CKnownFile::DrawShareStatusBar(wxDC *dc, wxRect rect, bool onlygreyrect, bool bFlat)
 {
  /*
  DWORD crBoth;
@@ -314,7 +315,7 @@ bool CKnownFile::LoadHashsetFromFile(CFile *file, bool checkhash)
         {
             memcpy(buffer + (i *16), hashlist[i], 16);
         }
-        CreateHashFromString(buffer, hashlist.GetCount() * 16, checkid);
+        CreateHashFromString(buffer, hashlist.GetCount() *16, checkid);
         delete[] buffer;
     }
     if (!memcmp(m_abyFileHash, checkid, 16))
@@ -494,7 +495,7 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
         file2->Read( &X, len *64);
         for (uint32 i = 0 ; i < len ; i++)
         {
-            MD42Transform(Hash, (uint32 *)(X + i *64));
+            MD4Transform(Hash, (uint32 *)(X + i *64));
         }
         Required -= len *64;
     }
@@ -515,7 +516,7 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
         X[Required] = 0x80;
         PaddingStarted = TRUE;
         memset( &X[Required + 1], 0, 63 - Required);
-        MD42Transform(Hash, (uint32 *) X);
+        MD4Transform(Hash, (uint32 *) X);
         Required = 0;
     }
     if (!PaddingStarted)
@@ -528,7 +529,7 @@ void CKnownFile::CreateHashFromInput(FILE *file, CFile *file2, int Length, uchar
     Length <<= 3;
     memcpy( &X[56], &Length, 4);
     memcpy( &X[60], &Length2, 4);
-    MD42Transform(Hash, (uint32 *) X);
+    MD4Transform(Hash, (uint32 *) X);
     memcpy(Output, Hash, 16);
     safe_delete(data);
 }
@@ -540,7 +541,7 @@ uchar *CKnownFile::GetPartHash(uint16 part)
     return hashlist[part];
 }
 
-static void MD42Transform(uint32 Hash[4], uint32 x[16])
+static void MD4Transform(uint32 Hash[4], uint32 x[16])
 {
     uint32 a = Hash[0];
     uint32 b = Hash[1];
@@ -548,103 +549,103 @@ static void MD42Transform(uint32 Hash[4], uint32 x[16])
     uint32 d = Hash[3];
     /* Round 1 */
     // 01:
-    MD42FF(a, b, c, d, x[ 0], S11);
+    MD4_FF(a, b, c, d, x[ 0], S11);
     // 02:
-    MD42FF(d, a, b, c, x[ 1], S12);
+    MD4_FF(d, a, b, c, x[ 1], S12);
     // 03:
-    MD42FF(c, d, a, b, x[ 2], S13);
+    MD4_FF(c, d, a, b, x[ 2], S13);
     // 04:
-    MD42FF(b, c, d, a, x[ 3], S14);
+    MD4_FF(b, c, d, a, x[ 3], S14);
     // 05:
-    MD42FF(a, b, c, d, x[ 4], S11);
+    MD4_FF(a, b, c, d, x[ 4], S11);
     // 06:
-    MD42FF(d, a, b, c, x[ 5], S12);
+    MD4_FF(d, a, b, c, x[ 5], S12);
     // 07:
-    MD42FF(c, d, a, b, x[ 6], S13);
+    MD4_FF(c, d, a, b, x[ 6], S13);
     // 08:
-    MD42FF(b, c, d, a, x[ 7], S14);
+    MD4_FF(b, c, d, a, x[ 7], S14);
     // 09:
-    MD42FF(a, b, c, d, x[ 8], S11);
+    MD4_FF(a, b, c, d, x[ 8], S11);
     // 10:
-    MD42FF(d, a, b, c, x[ 9], S12);
+    MD4_FF(d, a, b, c, x[ 9], S12);
     // 11:
-    MD42FF(c, d, a, b, x[10], S13);
+    MD4_FF(c, d, a, b, x[10], S13);
     // 12:
-    MD42FF(b, c, d, a, x[11], S14);
+    MD4_FF(b, c, d, a, x[11], S14);
     // 13:
-    MD42FF(a, b, c, d, x[12], S11);
+    MD4_FF(a, b, c, d, x[12], S11);
     // 14:
-    MD42FF(d, a, b, c, x[13], S12);
+    MD4_FF(d, a, b, c, x[13], S12);
     // 15:
-    MD42FF(c, d, a, b, x[14], S13);
+    MD4_FF(c, d, a, b, x[14], S13);
     // 16:
-    MD42FF(b, c, d, a, x[15], S14);
+    MD4_FF(b, c, d, a, x[15], S14);
     /* Round 2 */
     // 17:
-    MD42GG(a, b, c, d, x[ 0], S21);
+    MD4_GG(a, b, c, d, x[ 0], S21);
     // 18:
-    MD42GG(d, a, b, c, x[ 4], S22);
+    MD4_GG(d, a, b, c, x[ 4], S22);
     // 19:
-    MD42GG(c, d, a, b, x[ 8], S23);
+    MD4_GG(c, d, a, b, x[ 8], S23);
     // 20:
-    MD42GG(b, c, d, a, x[12], S24);
+    MD4_GG(b, c, d, a, x[12], S24);
     // 21:
-    MD42GG(a, b, c, d, x[ 1], S21);
+    MD4_GG(a, b, c, d, x[ 1], S21);
     // 22:
-    MD42GG(d, a, b, c, x[ 5], S22);
+    MD4_GG(d, a, b, c, x[ 5], S22);
     // 23:
-    MD42GG(c, d, a, b, x[ 9], S23);
+    MD4_GG(c, d, a, b, x[ 9], S23);
     // 24:
-    MD42GG(b, c, d, a, x[13], S24);
+    MD4_GG(b, c, d, a, x[13], S24);
     // 25:
-    MD42GG(a, b, c, d, x[ 2], S21);
+    MD4_GG(a, b, c, d, x[ 2], S21);
     // 26:
-    MD42GG(d, a, b, c, x[ 6], S22);
+    MD4_GG(d, a, b, c, x[ 6], S22);
     // 27:
-    MD42GG(c, d, a, b, x[10], S23);
+    MD4_GG(c, d, a, b, x[10], S23);
     // 28:
-    MD42GG(b, c, d, a, x[14], S24);
+    MD4_GG(b, c, d, a, x[14], S24);
     // 29:
-    MD42GG(a, b, c, d, x[ 3], S21);
+    MD4_GG(a, b, c, d, x[ 3], S21);
     // 30:
-    MD42GG(d, a, b, c, x[ 7], S22);
+    MD4_GG(d, a, b, c, x[ 7], S22);
     // 31:
-    MD42GG(c, d, a, b, x[11], S23);
+    MD4_GG(c, d, a, b, x[11], S23);
     // 32:
-    MD42GG(b, c, d, a, x[15], S24);
+    MD4_GG(b, c, d, a, x[15], S24);
     /* Round 3 */
     // 33:
-    MD42HH(a, b, c, d, x[ 0], S31);
+    MD4_HH(a, b, c, d, x[ 0], S31);
     // 34:
-    MD42HH(d, a, b, c, x[ 8], S32);
+    MD4_HH(d, a, b, c, x[ 8], S32);
     // 35:
-    MD42HH(c, d, a, b, x[ 4], S33);
+    MD4_HH(c, d, a, b, x[ 4], S33);
     // 36:
-    MD42HH(b, c, d, a, x[12], S34);
+    MD4_HH(b, c, d, a, x[12], S34);
     // 37:
-    MD42HH(a, b, c, d, x[ 2], S31);
+    MD4_HH(a, b, c, d, x[ 2], S31);
     // 38:
-    MD42HH(d, a, b, c, x[10], S32);
+    MD4_HH(d, a, b, c, x[10], S32);
     // 39:
-    MD42HH(c, d, a, b, x[ 6], S33);
+    MD4_HH(c, d, a, b, x[ 6], S33);
     // 40:
-    MD42HH(b, c, d, a, x[14], S34);
+    MD4_HH(b, c, d, a, x[14], S34);
     // 41:
-    MD42HH(a, b, c, d, x[ 1], S31);
+    MD4_HH(a, b, c, d, x[ 1], S31);
     // 42:
-    MD42HH(d, a, b, c, x[ 9], S32);
+    MD4_HH(d, a, b, c, x[ 9], S32);
     // 43:
-    MD42HH(c, d, a, b, x[ 5], S33);
+    MD4_HH(c, d, a, b, x[ 5], S33);
     // 44:
-    MD42HH(b, c, d, a, x[13], S34);
+    MD4_HH(b, c, d, a, x[13], S34);
     // 45:
-    MD42HH(a, b, c, d, x[ 3], S31);
+    MD4_HH(a, b, c, d, x[ 3], S31);
     // 46:
-    MD42HH(d, a, b, c, x[11], S32);
+    MD4_HH(d, a, b, c, x[11], S32);
     // 47:
-    MD42HH(c, d, a, b, x[ 7], S33);
+    MD4_HH(c, d, a, b, x[ 7], S33);
     // 48:
-    MD42HH(b, c, d, a, x[15], S34);
+    MD4_HH(b, c, d, a, x[15], S34);
     Hash[0] += a;
     Hash[1] += b;
     Hash[2] += c;
@@ -673,27 +674,33 @@ void CAbstractFile::SetFileName(char *NewName)
 
 //End by Tarod
 
-Packet *CKnownFile::CreateSrcInfoPacket(CUpDownClient *forClient)
+Packet* CKnownFile::CreateSrcInfoPacket(CUpDownClient* forClient)
 {
-    CTypedPtrList < CPtrList, CUpDownClient *> srclist;
+    CTypedPtrList<CPtrList, CUpDownClient *> srclist;
     //should we use "filehash"?:
-    theApp.uploadqueue->FindSourcesForFileById( &srclist, forClient->GetUploadFileID());
+    theApp.uploadqueue->FindSourcesForFileById(&srclist, forClient->GetUploadFileID());
+
     if (srclist.IsEmpty())
-    return 0;
+    {
+        return NULL;
+    }
+
     CMemFile data;
     uint16 nCount = 0;
     data.Write(forClient->GetUploadFileID(), 16);
     data.Write( &nCount, 2);
-    uint32 lastRequest = forClient->GetLastSrcReqTime();
+
     //we are only taking 30 random sources since we can't be sure if they have parts we need
     //this is hard coded because its a temp solution until next(?) version
     srand(time(NULL));
-    for (int i = 0 ; i < 30 ; i++)
+
+    for (int i=0; i<30; ++i)
     {
         int victim = ((rand() >> 7) % srclist.GetSize());
         POSITION pos = srclist.FindIndex(victim);
         CUpDownClient *cur_src = srclist.GetAt(pos);
-        if (!cur_src->HasLowID() &&cur_src != forClient)
+
+        if (!cur_src->HasLowID() && cur_src != forClient)
         {
             nCount++;
             uint32 dwID = cur_src->GetUserID();
@@ -705,20 +712,34 @@ Packet *CKnownFile::CreateSrcInfoPacket(CUpDownClient *forClient)
             data.Write( &dwServerIP, 4);
             data.Write( &nServerPort, 2);
             if (forClient->GetSourceExchangeVersion() > 1)
-            data.Write(cur_src->GetUserHash(), 16);
+            {
+                data.Write(cur_src->GetUserHash(), 16);
+            }
         }
+
         srclist.RemoveAt(pos);
+        
         if (srclist.GetSize() == 0)
-        break;
+        {
+            break;
+        }
     }
+
     if (!nCount)
-    return 0;
+    {
+        return NULL;
+    }
+
     data.Seek(16);
-    data.Write( &nCount, 2);
-    Packet *result = new Packet( &data, OP_EMULEPROT);
+    data.Write(&nCount, 2);
+    Packet* result = new Packet( &data, OP_EMULEPROT);
     result->opcode = OP_ANSWERSOURCES;
+
     if (nCount > 28)
-    result->PackPacket();
+    {
+        result->PackPacket();
+    }
+
     return result;
 }
 
@@ -756,58 +777,69 @@ void CKnownFile::UpdateAutoUpPriority(void)
 void CKnownFile::LoadComment()
 {
     char buffer[100];
-    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
+//    char *fullpath = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 13];
+//    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
     for (uint16 i = 0 ; i != 16 ; i++)
     sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
-    CIni ini(fullpath, buffer);
+    CIni ini(theApp.dynprefs->Get<wxString>("app-directory") + wxT("fileinfo.ini"), buffer);
     m_strComment = ini.GetString("Comment") .GetData();
     //For rate:
     m_iRate = ini.GetInt("Rate", 0);
     m_bCommentLoaded = true;
-    delete[] fullpath;
+//    delete[] fullpath;
 }
 
 void CKnownFile::SetFileComment(CString strNewComment)
 {
     char buffer[100];
-    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
+//    char* fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
+//    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
-    for (uint16 i = 0 ; i != 16 ; i++)
-    sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
-    CIni ini(fullpath, buffer);
+
+    for (uint16 i=0; i!=16; ++i)
+    {
+        sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
+    }
+
+    CIni ini(theApp.dynprefs->Get<wxString>("app-directory") + wxT("fileinfo.ini"), buffer);
     ini.WriteString("Comment", strNewComment);
     m_strComment = strNewComment;
-    delete fullpath;
+//    delete[] fullpath;
+
     CTypedPtrList < CPtrList, CUpDownClient *> srclist;
     theApp.uploadqueue->FindSourcesForFileById( &srclist, this->GetFileHash());
-    for (POSITION pos = srclist.GetHeadPosition() ; pos != 0 ; srclist.GetNext(pos))
+    
+    for (POSITION pos = srclist.GetHeadPosition(); pos != 0; srclist.GetNext(pos))
     {
-        CUpDownClient *cur_src = srclist.GetAt(pos);
+        CUpDownClient* cur_src = srclist.GetAt(pos);
         cur_src->SetCommentDirty();
     }
 }
 
-// For File rate
 void CKnownFile::SetFileRate(int8 iNewRate)
 {
     char buffer[100];
-    char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
-    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
+//    char* fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 13];
+//    sprintf(fullpath, "%sfileinfo.ini", theApp.glob_prefs->GetAppDir());
     buffer[0] = 0;
-    for (uint16 i = 0 ; i != 16 ; i++)
-    sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
-    CIni ini(fullpath, buffer);
+    
+    for (uint16 i=0; i!=16; ++i)
+    {
+        sprintf(buffer, "%s%02X", buffer, m_abyFileHash[i]);
+    }
+    
+    CIni ini(theApp.dynprefs->Get<wxString>("app-directory") + wxT("fileinfo.ini"), buffer);
     ini.WriteInt("Rate", iNewRate);
     m_iRate = iNewRate;
-    delete fullpath;
+//    delete[] fullpath;
+
     CTypedPtrList < CPtrList, CUpDownClient *> srclist;
     theApp.uploadqueue->FindSourcesForFileById( &srclist, this->GetFileHash());
+
     for (POSITION pos = srclist.GetHeadPosition() ; pos != 0 ; srclist.GetNext(pos))
     {
-        CUpDownClient *cur_src = srclist.GetAt(pos);
+        CUpDownClient* cur_src = srclist.GetAt(pos);
         cur_src->SetCommentDirty();
     }
 }
