@@ -1,5 +1,5 @@
 #ifndef MD5SUMH
-#define MD5SUMH
+#define MD5SUMH 1
 
 /* Copyright (C) 1991-2, RSA Data Security, Inc. Created 1991. All
 rights reserved.
@@ -22,8 +22,7 @@ without express or implied warranty of any kind.
 These notices must be retained in any copies of any part of this
 documentation and/or software.
  */
-
-#include <wx/string.h>                      // Needed for wxString
+#include <wx/string.h>
 
 class MD5Sum
 {
