@@ -17,25 +17,31 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+// OScopeCtrl.h : header file
+//
+
 #ifndef __OScopeCtrl_H__
 #define __OScopeCtrl_H__
 
-#include "mfc.h"                            // Needed for CString 
-#include "wintypes.h"                       // Needed for COLORREF
-
-#include <wx/control.h>                     // Needed for wxControl
-#include <wx/dc.h>                          // Needed for wxBrush
-#include <wx/timer.h>                       // Needed for wxTimer
-
-class wxMemoryDC;
+#include "mfc.h"
+#include "wintypes.h"
 
+#include <wx/control.h>
+#include <wx/dcmemory.h>
+#include <wx/bitmap.h>
+#include <wx/timer.h>
 #define RGB(a,b,c) ((a&0xff)<<16|(b&0xff)<<8|(c&0xff))
+
+/////////////////////////////////////////////////////////////////////////////
+// COScopeCtrl window
+
 #define TIMER_OSCOPE 7641
 
-class COScopeCtrl: public wxControl
+class COScopeCtrl : public wxControl
 {
+// Construction
 public:
-	COScopeCtrl(int NTrends = 1, wxWindow* parent = NULL );
+	COScopeCtrl( int NTrends=1, wxWindow* parent=NULL );
 
 // Attributes
 public:
@@ -43,8 +49,8 @@ public:
 	void AppendEmptyPoints(double dNewPoint[], bool bInvalidate = true, bool bAdd2List = true);
 	void SetRange(double dLower, double dUpper, int iTrend = 0);
 	void SetRanges(double dLower, double dUpper);
-	void SetXUnits(CString string, CString XMin = "", CString XMax = "");
-	void SetYUnits(CString string, CString YMin = "", CString YMax = "");
+	void SetXUnits(wxString string, wxString XMin = "", wxString XMax = "");
+	void SetYUnits(wxString string, wxString YMin = "", wxString YMax = "");
 	void SetGridColor(COLORREF color);
 	void SetPlotColor(COLORREF color, int iTrend = 0);
 	COLORREF GetPlotColor(int iTrend = 0);
@@ -53,6 +59,15 @@ public:
 	void DrawPoint();
 	void Reset();
 
+	// Operations
+public:
+
+// Overrides
+	// ClassWizard generated virtual function overrides
+	//{{AFX_VIRTUAL(COScopeCtrl)
+	public:
+	//virtual BOOL Create(DWORD dwStyle, const RECT& rect, CWnd* pParentWnd, UINT nID=NULL);
+	//}}AFX_VIRTUAL
 
  private:
 	int oldwidth,oldheight;
@@ -74,8 +89,8 @@ public:
 	int m_nYDecimals;
 
 	typedef struct m_str_struct {	
-		CString XUnits, XMin, XMax;
-		CString YUnits, YMin, YMax;
+		wxString XUnits, XMin, XMax;
+		wxString YUnits, YMin, YMax;
 	} m_str_t;
 	m_str_t m_str;
 
@@ -92,6 +107,7 @@ public:
 		double dUpperLimit;         // upper bounds
 		double dRange;				// = UpperLimit - LowerLimit
 		double dVerticalFactor;
+	  //CList<double,double> lstPoints;
 	  CList<float,float> lstPoints;
 	} PlotData_t ;
 
@@ -100,6 +116,14 @@ public:
 	// Generated message map functions
 protected:
 	int m_NTrends;
+
+#if 0
+	//{{AFX_MSG(COScopeCtrl)
+	afx_msg void OnPaint();
+	afx_msg void OnSize(UINT nType, int cx, int cy); 
+	//}}AFX_MSG
+	DECLARE_MESSAGE_MAP()
+#endif
 	  void OnPaint(wxPaintEvent& evt);
 	void OnSize(wxSizeEvent& evt);
 
@@ -130,9 +154,11 @@ protected:
 	wxBitmap *m_bitmapPlot;
 
 	bool m_bDoUpdate;
+	//UINT m_nRedrawTimer;
 	wxTimer m_nRedrawTimer;
 public:
 	int ReCreateGraph(void);
+	//afx_msg void OnTimer(UINT nIDEvent);
 	void OnTimer(wxTimerEvent& evt);
 
 	void GetPlotRect(RECT& rPlotRect)
@@ -141,4 +167,5 @@ public:
 	}
 };
 
+/////////////////////////////////////////////////////////////////////////////
 #endif
