@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,20 +14,29 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+
 #ifndef SEARCHLIST_H
 #define SEARCHLIST_H
 
-#include "KnownFile.h"                      // Needed for CAbstractFile
-#include "wintypes.h"                       // Needed for LPCTSTR
+#include "opcodes.h"
+#include "xmule.h"
+#include "types.h"
+#include "KnownFile.h"
+#include "otherfunctions.h"
+#include "SafeFile.h"
+
+class CPreferences;
+class Packet;
 
 class CSearchFile : public CAbstractFile {
 	friend class CPartFile;
 public:
+	//CSearchFile() {};
 	CSearchFile(char* data, wxUint32 nSearchID);
 	CSearchFile(CFile* in_data, wxUint32 nSearchID, wxUint32 nServerIP=0, uint16 nServerPort=0, LPCTSTR pszDirectory = NULL);
 	CSearchFile(wxUint32 nSearchID, const uchar* pucFileHash, wxUint32 uFileSize, char *pszFileName, int iFileType, int iAvailability);
@@ -102,6 +111,7 @@ private:
 	uint16	 m_list_childcount;
 	CSearchFile* m_list_parent;
 	bool		 m_bPreviewPossible;
+	//CArray<CxImage*,CxImage*> m_listImages;
 	char *m_pszDirectory;
 };
 #endif
