@@ -3,54 +3,76 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
 // version 2 of the License, or (at your option) any later version.
-//
+// 
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-#ifdef PRECOMP
-    #include "xmule-headers.h"
-#endif
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif // HAVE_CONFIG_H
 
-#include "ServerList.h"                     // Needed for this Interface's Prototype
-
-#include "ldaemon.h"                        // Needed for CLDaemon
-#include "ListenSocket.h"                   // Needed for TooManySockets
-#include "otherfunctions.h"                 // Needed for GetTickCount
-#include "PartFile.h"                       // Needed for SRV_PR_HIGH
-#include "Preferences.h"                    // Needed for CPreferences
-#include "DownloadQueue.h"                  // Needed for CDownloadQueue
-#include "HTTPDownloadDlg.h"                // Needed for CHTTPDownloadDlg
-#include "otherstructs.h"                   // Needed for ServerMet_Struct
-#include "packets.h"                        // Needed for CTag
-#include "SafeFile.h"                       // Needed for CSafeFile
-#include "server.h"                         // Needed for CServer
-#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
-#include "ServerWnd.h"                      // Needed for CServerWnd
-#include "sockets.h"                        // Needed for CServerConnect
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for xmuleDlg
+// Test if we have _GNU_SOURCE before the next step will mess up
+// setting __USE_GNU
+// (only needed for gcc-2.95 compatibility, gcc 3.2 always defines it)
+#include "wx/setup.h"
 
 // Mario Sergio Fujikawa Ferreira <lioux@FreeBSD.org>
 // to detect if this is a *BSD system
 #if defined(HAVE_SYS_PARAM_H)
-    #include <sys/param.h>
+#include <sys/param.h>
 #endif
 
-#include <wx/filename.h>                    // Needed for wxFileName
-#include <wx/menu.h>                        // Needed for wxMenu
-#include <wx/msgdlg.h>                      // Needed for wxMessageBox
+#ifdef PRECOMP
+#	include "xmule-headers.h"
+#else
+#	include "DownloadQueue.h"
+#	include "HTTPDownloadDlg.h"
+#include "ListenSocket.h"                   // CListenSocket
+#include "packets.h"                        // Packet
+#include "Preferences.h"                    // CPreferences::address_list
+#include "SafeFile.h"                       // CSafeMemFile
+#	include "ServerList.h"
+#	include "ServerWnd.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
+#endif
+
+#if !HAVE_CRYPTO
+    #include "CryptoXMpp.h"
+#else
+    #include <cryptopp/cryptlib.h>
+    #include <cryptopp/rsa.h>
+    #define CryptoXMpp CryptoPP
+#endif
+
+#ifdef WORDS_BIGENDIAN
+    #define LE_BE(X) CryptoXMpp::ByteReverse(X)
+#else
+    #define LE_BE(X) X
+#endif
+
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
+
+#include <wx/msgdlg.h>
+
+#include <wx/listimpl.cpp>
+//WX_DEFINE_LIST(CServerListList);
+
+#include <iostream>
+using std::cout;
+using std::endl;
 
 CServerList::CServerList(CPreferences *in_prefs):
 list(wxKEY_NONE)
@@ -67,16 +89,6 @@ list(wxKEY_NONE)
     m_nLastSaved =::GetTickCount();
 }
 
-CServer* CServerList::GetServerAt(wxUint32 pos)
-{
-    return list.GetAt(list.FindIndex(pos));
-}
-
-wxUint32 CServerList::GetServerCount()
-{
-    return list.GetCount();
-}
-
 void CServerList::AutoUpdate()
 {
     if (app_prefs->adresses_list.IsEmpty())
@@ -85,12 +97,10 @@ void CServerList::AutoUpdate()
         return;
     }
     bool bDownloaded = false;
-    CString servermetdownload;
-    //  CString servermetbackup;
-    CString servermet;
-    CString strURLToDownload;
-    servermetdownload.Format("%sserver_met.download", app_prefs->GetAppDir());
-    servermet.Format("%sserver.met", app_prefs->GetAppDir());
+
+    wxString servermetdownload(theApp.dynprefs->Get<wxString>("app-directory") + wxT("server_met.download"));
+    wxString servermet(theApp.dynprefs->Get<wxString>("app-directory") + wxT("server.met"));
+    wxString strURLToDownload;
     BackupFile(servermet, ".old");
     wxRemoveFile(servermetdownload);
     POSITION Pos = app_prefs->adresses_list.GetHeadPosition();
@@ -107,7 +117,7 @@ void CServerList::AutoUpdate()
         }
         else
         {
-            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET), strURLToDownload.GetBuffer());
+            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FAILEDDOWNLOADMET), strURLToDownload.c_str());
         }
         delete dlgDownload;
     }
@@ -126,25 +136,24 @@ void CServerList::AutoUpdate()
 bool CServerList::Init()
 {
     // auto update the list by using an url
-    if (app_prefs->AutoServerlist())
+    if (theApp.dynprefs->Get<bool>("autoupdate-server"))
     AutoUpdate();
     // Load Metfile
-    CString strPath;
 #if defined(__DEBUG__)
     printf("*** reading servers\n");
 #endif
-    strPath.Format("%sserver.met", app_prefs->GetAppDir());
-    bool bRes = AddServermetToList(strPath, false);
-    if (theApp.glob_prefs->AutoServerlist())
+    wxString strPath(theApp.dynprefs->Get<wxString>("app-directory") + wxT("server.met"));
+    bool bRes = AddServermetToList(static_cast<CString>(strPath), false);
+
+    if (theApp.dynprefs->Get<bool>("autoupdate-server"))
     {
-        strPath.Format("%sserver.met", app_prefs->GetAppDir());
-        bool bRes2 = AddServermetToList(strPath);
+        bool bRes2 = AddServermetToList(static_cast<CString>(strPath));
         if (!bRes &&bRes2)
         bRes = true;
     }
     // insert static servers from textfile
-    strPath.Format("%sstaticservers.dat", app_prefs->GetAppDir());
-    AddServersFromTextFile(strPath);
+    strPath = theApp.dynprefs->Get<wxString>("app-directory") + wxT("staticservers.dat");
+    AddServersFromTextFile(static_cast<CString>(strPath));
     return bRes;
 }
 
@@ -162,13 +171,14 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
         theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
-    if (!servermet.Open(strFile.c_str(), CFile::read))
+    if (!servermet.Open(strFile, CFile::read))
     {
         //CFile::modeRead|CFile::osSequentialScan)){
         theApp.xmuledlg->AddLogLine(false, _("Failed to load server.met!"));
         return false;
     }
-    if ((1 != servermet.Read( &version, 1)) || (version != 0xE0 && version != MET_HEADER))
+    if ((1 != servermet.Read( &version, 1)) ||
+    (version != 0xE0 && version != MET_HEADER))
     {
         servermet.Close();
         theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_BADSERVERMETVERSION), version);
@@ -176,21 +186,25 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
     }
     try
     {
-        wxUint32 fservercount;
+        uint32 fservercount;
         if (4 != servermet.Read( &fservercount, 4))
         throw CInvalidPacket();
+	fservercount = LE_BE((CryptoXMpp::word32)fservercount);
         ServerMet_Struct sbuffer;
-        wxUint32 iAddCount = 0;
+        uint32 iAddCount = 0;
         theApp.xmuledlg->serverwnd->serverlistctrl->Freeze();
-        for (wxUint32 j = 0 ; j < fservercount ; j++)
+        for (uint32 j = 0 ; j < fservercount ; j++)
         {
             // get server
             if (sizeof(ServerMet_Struct) != servermet.Read( &sbuffer, sizeof(ServerMet_Struct)))
             throw CInvalidPacket();
             CServer *newserver = new CServer( &sbuffer);
             //add tags
-            for (wxUint32 i = 0 ; i < sbuffer.tagcount ; i++)
-            newserver->AddTagFromFile( &servermet);
+            for (uint32 i = 0; i < LE_BE((CryptoXMpp::word32)sbuffer.tagcount); i++)
+            {
+                newserver->AddTagFromFile(&servermet);
+            }
+
             // set listname for server
             if (!newserver->GetListName())
             {
@@ -232,12 +246,27 @@ bool CServerList::AddServermetToList(CString strFile, bool merge)
         return false;
     }
     servermet.Close();
+#if 0
+    catch(CFileException *error)
+    {
+        if (error->m_cause == CFileException::endOfFile)
+        theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_BADSERVERLIST));
+        else
+        {
+            char buffer[150];
+            error->GetErrorMessage(buffer, 150);
+            theApp.xmuledlg->AddLogLine(true, GetResString(IDS_ERR_FILEERROR_SERVERMET), buffer);
+        }
+        //memleak fix:
+        error->Delete();
+    }
+#endif
     return true;
 }
 
 bool CServerList::AddServer(CServer *in_server)
 {
-    if (theApp.glob_prefs->FilterBadIPs())
+    if (theApp.dynprefs->Get<bool>("filter-bad-ip") == true)
     if (!IsGoodServerIP(in_server))
     return false;
     CServer *test_server = GetServerByAddress(in_server->GetAddress(), in_server->GetPort());
@@ -266,21 +295,21 @@ void CServerList::ServerStats()
             if (ping_server == test)
             return;
         }
-        if (ping_server->GetFailedCount() >= theApp.glob_prefs->GetDeadserverRetries() &&theApp.glob_prefs->DeadServer())
+        if (ping_server->GetFailedCount() >= theApp.dynprefs->Get<long>("server-connect-tries") && theApp.dynprefs->Get<bool>("remove-dead-server"))
         {
             theApp.xmuledlg->serverwnd->serverlistctrl->RemoveServer(ping_server);
             return;
         }
         Packet *packet = new Packet(OP_GLOBSERVSTATREQ, 4);
         srand((unsigned) time(NULL));
-        wxUint32 time = 0x55AA0000 + (wxUint16) rand();
+        uint32 time = 0x55AA0000 + (uint16) rand();
         ping_server->SetChallenge(time);
         memcpy(packet->pBuffer, &time, 4);
         ping_server->SetLastPinged(::GetTickCount());
         ping_server->AddFailedCount();
         theApp.xmuledlg->serverwnd->serverlistctrl->RefreshServer(ping_server);
 #if defined(__DEBUG__)
-//  printf("CServerList::ServerStats --> OP_GLOBSERVSTATREQ size=%d\n",packet->size);
+//	printf("CServerList::ServerStats --> OP_GLOBSERVSTATREQ size=%d\n",packet->size);
 #endif
         theApp.serverconnect->SendUDPPacket(packet, ping_server, true);
     }
@@ -346,7 +375,7 @@ void CServerList::RemoveAllServers()
     }
 }
 
-void CServerList::GetStatus(wxUint32 &total, wxUint32 &failed, wxUint32 &user, wxUint32 &file, wxUint32 &tuser, wxUint32 &tfile, float &occ)
+void CServerList::GetStatus(uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ)
 {
     total = list.GetCount();
     failed = 0;
@@ -355,8 +384,8 @@ void CServerList::GetStatus(wxUint32 &total, wxUint32 &failed, wxUint32 &user, w
     tuser = 0;
     tfile = 0;
     occ = 0;
-    wxUint32 maxusers = 0;
-    wxUint32 tuserk = 0;
+    uint32 maxusers = 0;
+    uint32 tuserk = 0;
     CServer *curr;
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -382,7 +411,7 @@ void CServerList::GetStatus(wxUint32 &total, wxUint32 &failed, wxUint32 &user, w
     if (maxusers > 0) occ = (float)(tuserk *100) /maxusers;
 }
 
-void CServerList::GetUserFileStatus(wxUint32 &user, wxUint32 &file)
+void CServerList::GetUserFileStatus(uint32 &user, uint32 &file)
 {
     user = 0;
     file = 0;
@@ -436,6 +465,10 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
     if (!stream.Ok())
     return;
     wxTextInputStream f(stream);
+#if 0
+    if (!f.Open(strFilename, "r"))
+    return;
+#endif
     while (strLine = f.ReadLine())
     {
         // stop iteration if end of file is met..:
@@ -484,10 +517,6 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
         strName.Replace("\r", "");
         strName.Replace("\n", "");
         // create server object and add it to the list
-        if (theApp.daemon == true)
-        {
-            theApp.lda->Print (strName + wxString(" - ") + strPort, LD_SERVER);
-        }
         CServer *nsrv = new CServer(atoi(strPort), (char *) strHost.GetData());
         nsrv->SetListName((char *) strName.GetData());
         nsrv->SetIsStaticMember(true);
@@ -514,7 +543,7 @@ void CServerList::AddServersFromTextFile(CString strFilename, bool isstaticserve
 void CServerList::MoveServerDown(CServer *aServer)
 {
     POSITION pos1, pos2;
-    wxUint16 i = 0;
+    uint16 i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -534,7 +563,7 @@ void CServerList::MoveServerDown(CServer *aServer)
 void CServerList::Sort()
 {
     POSITION pos1, pos2;
-    wxUint16 i = 0;
+    uint16 i = 0;
     for (pos1 = list.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         list.GetNext(pos1);
@@ -558,8 +587,8 @@ void CServerList::Sort()
 CServer *CServerList::GetNextServer()
 {
     CServer *nextserver = 0;
-    wxUint32 i = 0;
-    if (serverpos >= ((wxUint32) list.GetCount())) return 0;
+    uint32 i = 0;
+    if (serverpos >= ((uint32) list.GetCount())) return 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(serverpos);
@@ -575,8 +604,8 @@ CServer *CServerList::GetNextServer()
         i++;
         // TODO: Add more option to filter bad server like min ping, min users etc
         //if (nextserver->preferences = ?)
-        //  nextserver = 0;
-        //if (serverpos == list.GetCount()) return 0;//         serverpos = 0;
+        //	nextserver = 0;
+        //if (serverpos == list.GetCount()) return 0;//			serverpos = 0;
     }
     return nextserver;
 }
@@ -584,7 +613,7 @@ CServer *CServerList::GetNextServer()
 CServer *CServerList::GetNextSearchServer()
 {
     CServer *nextserver = 0;
-    wxUint32 i = 0;
+    uint32 i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(searchserverpos);
@@ -606,7 +635,7 @@ CServer *CServerList::GetNextSearchServer()
 CServer *CServerList::GetNextStatServer()
 {
     CServer *nextserver = 0;
-    wxUint32 i = 0;
+    uint32 i = 0;
     while (!nextserver &&i != list.GetCount())
     {
         POSITION posIndex = list.FindIndex(statserverpos);
@@ -651,7 +680,7 @@ void CServerList::SendNextPacket()
         CServer *cur_server = list.GetAt(broadcastpos);
         if (cur_server != theApp.serverconnect->GetCurrentServer())
 #if defined(__DEBUG__)
-    printf("CServerList::ServerStats --> %02 size=%d\n",broadcastpacket->opcode,broadcastpacket->size);
+	printf("CServerList::ServerStats --> %02 size=%d\n",broadcastpacket->opcode,broadcastpacket->size);
 #endif
         theApp.serverconnect->SendUDPPacket(broadcastpacket, cur_server, false);
         list.GetNext(broadcastpos);
@@ -675,6 +704,14 @@ void CServerList::CancelUDPBroadcast()
     }
 }
 
+#if 0
+void CALLBACK CServerList::UDPTimerProc(HWND hwnd, UINT uMsg, UINT_PTR idEvent, DWORD dwTime)
+{
+    theApp.serverlist->SendNextPacket();
+}
+
+#endif
+
 CServer *CServerList::GetNextServer(CServer *lastserver)
 {
     if (list.IsEmpty())
@@ -714,7 +751,7 @@ CServer *CServerList::GetServerByIP(wxUint32 nIP, wxUint16 nPort)
     return NULL;
 }
 
-CServer *CServerList::GetServerByAddress(char *address, wxUint16 port)
+CServer *CServerList::GetServerByAddress(char *address, uint16 port)
 {
     for (POSITION pos = list.GetHeadPosition() ; pos != 0 ; list.GetNext(pos))
     {
@@ -730,9 +767,9 @@ bool CServerList::SaveServermetToFile()
 {
     // oops.. don't save ALL the time :):
     m_nLastSaved =::GetTickCount();
-    char *newservermet = new char[strlen(app_prefs->GetAppDir()) + MAX_PATH];
-    sprintf(newservermet, "%sserver.met.new", app_prefs->GetAppDir());
-    //  theApp.xmuledlg->AddLogLine( false, "%s", newservermet );
+    char *newservermet = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + MAX_PATH];
+    sprintf(newservermet, "%sserver.met.new", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
+    //	theApp.xmuledlg->AddLogLine( false, "%s", newservermet );
     {
         FILE *servermet = fopen(newservermet, "wb");
         if (!servermet)
@@ -743,24 +780,29 @@ bool CServerList::SaveServermetToFile()
             return false;
         }
         version = 0xE0;
+        version = LE_BE((CryptoXMpp::word32)version);
+
         fwrite( &version, 1, 1, servermet);
-        wxUint32 fservercount = list.GetCount();
-        fwrite( &fservercount, 4, 1, servermet);
+        
+        uint32 fservercount = list.GetCount();
+        uint32 w_fservercount = LE_BE((CryptoXMpp::word32)fservercount);
+        fwrite(&w_fservercount, 4, 1, servermet);
+
         ServerMet_Struct sbuffer;
         CServer *nextserver;
-        for (wxUint32 j = 0 ; j != fservercount ; j++)
+        for (uint32 j = 0 ; j != fservercount ; j++)
         {
             nextserver = this->GetServerAt(j);
-            sbuffer.ip = nextserver->GetIP();
-            sbuffer.port = nextserver->GetPort();
-            wxUint16 tagcount = 11;
+            sbuffer.ip = LE_BE((CryptoXMpp::word32)nextserver->GetIP());
+            sbuffer.port = LE_BE((CryptoXMpp::word32)nextserver->GetPort());
+            uint16 tagcount = 11;
             if (nextserver->GetListName())
             tagcount++;
             if (nextserver->GetDynIP())
             tagcount++;
             if (nextserver->GetDescription())
             tagcount++;
-            sbuffer.tagcount = tagcount;
+            sbuffer.tagcount = LE_BE((CryptoXMpp::word32)tagcount);
             fwrite( &sbuffer, 1, sizeof(sbuffer), servermet);
             if (nextserver->GetListName())
             {
@@ -801,16 +843,27 @@ bool CServerList::SaveServermetToFile()
             tagUDPFlags.WriteTagToFile(servermet);
         }
         fclose(servermet);
-        char *curservermet = new char[strlen(app_prefs->GetAppDir()) + 20];
-        char *oldservermet = new char[strlen(app_prefs->GetAppDir()) + 20];
-        sprintf(curservermet, "%sserver.met", app_prefs->GetAppDir());
-        sprintf(oldservermet, "%sserver_met.old", app_prefs->GetAppDir());
+        char *curservermet = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 20];
+        char *oldservermet = new char[theApp.dynprefs->Get<wxString>("app-directory").length() + 20];
+        sprintf(curservermet, "%sserver.met", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
+        sprintf(oldservermet, "%sserver_met.old", static_cast<const char *>(theApp.dynprefs->Get<wxString>("app-directory").c_str()));
         wxRemoveFile(oldservermet);
         wxRenameFile(curservermet, oldservermet);
         wxRenameFile(newservermet, curservermet);
         delete[] oldservermet;
         delete[] curservermet;
     }
+#if 0
+    catch(CFileException *error)
+    {
+        OUTPUT_DEBUG_TRACE();
+        theApp.xmuledlg->AddLogLine(false, GetResString(IDS_ERR_SAVESERVERMET2));
+        //mf:
+        delete[] newservermet;
+        error->Delete();
+        return false;
+    }
+#endif
     delete[] newservermet;
     return true;
 }
@@ -821,4 +874,3 @@ void CServerList::Process()
     this->SaveServermetToFile();
 }
 
-
