@@ -3,7 +3,7 @@
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
-// Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.emule-project.net )
+//Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -14,20 +14,22 @@
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-//
+// 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
+
 #ifndef SERVERLIST_H
 #define SERVERLIST_H
 
-#include "mfc.h"                            // Needed for CString
+#include "server.h"
+#include "opcodes.h"
+#include "ServerListCtrl.h"
 
-#include <wx/timer.h>                       // Needed for wxTimer
+#include <wx/timer.h>
 
 class CPreferences;
-class CServer;
 class Packet;
 
 class CServerList
@@ -49,41 +51,42 @@ public:
 	CServer*	GetNextServer();
 	CServer*	GetNextSearchServer();
 	CServer*	GetNextStatServer();
-	CServer*	GetServerAt(wxUint32 pos);
-	wxUint32	GetServerCount();
+	CServer*	GetServerAt(uint32 pos)	{return list.GetAt(list.FindIndex(pos));}
+	uint32		GetServerCount()	{return list.GetCount();}
 	CServer*	GetNextServer(CServer* lastserver); // slow
 	CServer*	GetServerByIP(wxUint32 nIP);
 	CServer*	GetServerByIP(wxUint32 nIP,wxUint16 nPort);
-	CServer*	GetServerByAddress(char* address, wxUint16 port);
+	CServer*	GetServerByAddress(char* address, uint16 port);
 	bool		IsGoodServerIP( CServer* in_server ); //<<--
-	void		GetStatus( wxUint32 &total, wxUint32 &failed, wxUint32 &user, wxUint32 &file, wxUint32 &tuser, wxUint32 &tfile, float &occ);
-	void		GetUserFileStatus( wxUint32 &user, wxUint32 &file);
+	void		GetStatus( uint32 &total, uint32 &failed, uint32 &user, uint32 &file, uint32 &tuser, uint32 &tfile, float &occ);
+	void		GetUserFileStatus( uint32 &user, uint32 &file);
 	bool		BroadCastPacket(Packet* packet); //send Packet to all server in the list
 	void		CancelUDPBroadcast();
 	void		Sort();
 	void		MoveServerDown(CServer* aServer);
-	wxUint32		GetServerPostion()	{return serverpos;}
-	void		SetServerPosition(wxUint32 newPosition) { if (newPosition<(wxUint32)list.GetCount() ) serverpos=newPosition; else serverpos=0;}
-	wxUint32		GetDeletedServerCount()		{return delservercount;}
+	uint32		GetServerPostion()	{return serverpos;}
+	void		SetServerPosition(uint32 newPosition) { if (newPosition<(uint32)list.GetCount() ) serverpos=newPosition; else serverpos=0;}
+	uint32		GetDeletedServerCount()		{return delservercount;}
 	void		Process();
 	void		SendNextPacket();
 
+	//void static CALLBACK UDPTimerProc(HWND hwnd, UINT uMsg,UINT_PTR idEvent,DWORD dwTime);
 protected:
 	void		AutoUpdate();
-
 private:
-	wxUint32		serverpos;
-	wxUint32		searchserverpos;
-	wxUint32		statserverpos;
-	wxUint8		version;
-	wxUint32		servercount;
+	uint32		serverpos;
+	uint32		searchserverpos;
+	uint32		statserverpos;
+	int8		version;
+	uint32		servercount;
 	CTypedPtrList<CPtrList, CServer*>	list;
 	CPreferences*	app_prefs;
+	//uint32		udp_timer;
 	wxTimer         udp_timer;
 	POSITION	broadcastpos;
 	Packet*		broadcastpacket;
-	wxUint32		delservercount;
-	wxUint32		m_nLastSaved;
+	uint32		delservercount;
+	uint32		m_nLastSaved;
 };
 
 #endif
