@@ -1,10 +1,10 @@
 // This file is a part of the xMule Project.
-// 
+//
 // Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
 // DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
 //
 // Copyright (C)2002 Merkur ( merkur-@users.sourceforge.net / http://www.xmule-project.net )
-// 
+//
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either
@@ -20,37 +20,30 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "DownloadQueue.h"
+#	include "FriendList.h"
+#	include "ini2.h"
+#	include "KnownFile.h"
+#	include "ListenSocket.h"
+#	include "packets.h"
+#include "Preferences.h"                    // CPreferences::GetQueueSize
+#	include "ServerWnd.h"
+#	include "SharedFileList.h"
+#	include "StatisticsDlg.h"
+#	include "TransferWnd.h"
+#	include "UploadQueue.h"
+#	include "wintypes.h"
+#	include "xmule.h"
+#	include "xmuleDlg.h"
 #endif
 
-#include "UploadQueue.h"                    // Needed for this Interface's Prototype
+#include "DynPrefs/DynPrefs.h"              // Needed for DynamicPreferences
 
-#include "ClientCredits.h"                  // Needed for CClientCreditsList
-#include "DownloadQueue.h"                  // Needed for CDownloadQueue
-#include "FriendList.h"                     // Needed for CFriendList
-#include "ini2.h"                           // Needed for CIni
-#include "KnownFile.h"                      // Needed for CKnownFile
-#include "ldaemon.h"                        // Needed for CLDaemon
-#include "ListenSocket.h"                   // Needed for CClientReqServer
-#include "otherfunctions.h"                 // Needed for GetResString
-#include "packets.h"                        // Needed for Packet
-#include "Preferences.h"                    // Needed for CPreferences
-#include "QueueListCtrl.h"                  // Needed for CQueueListCtrl
-#include "server.h"                         // Needed for CServer
-#include "ServerList.h"                     // Needed for CServerList
-#include "ServerListCtrl.h"                 // Needed for CServerListCtrl
-#include "ServerWnd.h"                      // Needed for CServerWnd
-#include "SharedFileList.h"                 // Needed for CSharedFileList
-#include "sockets.h"                        // Needed for CServerConnect
-#include "StatisticsDlg.h"                  // Needed for CStatisticsDlg
-#include "TransferWnd.h"                    // Needed for CTransferWnd
-#include "updownclient.h"                   // Needed for CUpDownClient
-#include "UploadListCtrl.h"                 // Needed for CUploadListCtrl
-#include "xmule.h"                          // Needed for theApp
-#include "xmuleDlg.h"                       // Needed for theApp.xmuledlg
-
-#include <arpa/inet.h>                      // Needed for in_addr
-#include <cmath>                            // Needed for ceil
+#include <string.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
 
 #define ID_UQTIMER 59742
 
@@ -67,7 +60,7 @@ static uint32 counter, sec, statsave;
 
 static uint32 igraph, istats;
 
-CUploadQueue::CUploadQueue(CPreferences* in_prefs)
+CUploadQueue::CUploadQueue(CPreferences *in_prefs)
 {
     app_prefs = in_prefs;
     //h_timer = SetTimer(0,141,100,TimerProc);
@@ -131,7 +124,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
                 // finished clearing
             }
             else if((cur_client->GetScore(true) > bestscore)
-            && (!cur_client->HasLowID() || (cur_client->socket && cur_client->socket->IsConnected())))
+            && (!cur_client->HasLowID() || (cur_client->socket &&cur_client->socket->IsConnected())))
             {
                 bestscore = cur_client->GetScore(true);
                 toadd = pos2;
@@ -230,7 +223,7 @@ void CUploadQueue::AddUpNextClient(CUpDownClient *directadd)
     (newclient->m_clientModString.Cmp("|X|") == 0) ||
     ((newclient->m_clientModString.IsEmpty() == false) && (newclient->GetClientSoft() != SO_EMULE) && (newclient->GetClientSoft() != SO_XMULE)) ||
     ((!newclient->GetMuleVersion() && (newclient->GetClientSoft() == SO_EMULE || newclient->GetClientSoft() == SO_OLDEMULE)) && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
-    (!newclient->ExtProtocolAvailable() && newclient->GetClientSoft() == SO_EMULE && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
+    (!newclient->ExtProtocolAvailable() &&newclient->GetClientSoft() == SO_EMULE && (newclient->GetVersion() == 60 || !newclient->GetVersion())) ||
     ((newclient->GetVersion() > 589) && (newclient->GetSourceExchangeVersion() > 0) && (newclient->GetClientSoft() == SO_EDONKEY)))
     )
     {
@@ -272,53 +265,46 @@ void CUploadQueue::Process()
     m_nSumForAvgDataRate -= avarage_dr_list.RemoveHead();
     avarage_dr_list.AddTail(dataratems);
     m_nSumForAvgDataRate += dataratems;
-    datarate = 10 * m_nSumForAvgDataRate / avarage_dr_list.GetCount();
+    datarate = 10 *m_nSumForAvgDataRate / avarage_dr_list.GetCount();
     dataratems = 0;
-
-    if (AcceptNewClient() && waitinglist.GetCount())
+    if (AcceptNewClient() &&waitinglist.GetCount())
     {
-        m_nLastStartUpload = ::GetTickCount();
+        m_nLastStartUpload =::GetTickCount();
         AddUpNextClient();
     }
-    
     if (!uploadinglist.GetCount())
-    {
-        return;
-    }
-    
+    return;
     int16 clientsrdy = 0;
-    
     for (POSITION pos = uploadinglist.GetHeadPosition() ; pos != 0 ; uploadinglist.GetNext(pos))
     {
         CUpDownClient *cur_client = uploadinglist.GetAt(pos);
-        if ((cur_client->socket) && (!cur_client->socket->IsBusy()) && cur_client->HasBlocks())
-        {
-            ++clientsrdy;
-        }
+        if ((cur_client->socket) && (!cur_client->socket->IsBusy()) &&cur_client->HasBlocks())
+        clientsrdy++;
     }
-    
     if (!clientsrdy)
     {
         estadatarate -= 200;
         if (estadatarate < 100)
-        {
-            estadatarate = 100;
-        }
-        ++clientsrdy;
+        estadatarate = 100;
+        clientsrdy++;
     }
     else
     {
         estadatarate += 200;
-        
-        if (estadatarate > app_prefs->GetMaxUpload() * 102)
+
+        long upload_rate(0);
+        if ((upload_rate = theApp.dynprefs->Get<long>("limits-upload")) == UNLIMITED)
         {
-            estadatarate = app_prefs->GetMaxUpload() * 102;
+            upload_rate = 1000000000L;
+        }
+
+        if (estadatarate > upload_rate * 102)
+        {
+            estadatarate = upload_rate * 102;
         }
     }
-
     uint32 sendperclient = estadatarate / clientsrdy;
     POSITION pos1, pos2;
-    
     for (pos1 = uploadinglist.GetHeadPosition() ; (pos2 = pos1) != NULL ;)
     {
         uploadinglist.GetNext(pos1);
@@ -327,34 +313,24 @@ void CUploadQueue::Process()
     }
 }
 
+;
+
 bool CUploadQueue::AcceptNewClient()
 {
-    // check if we can allow a new client to start downloading from us
+    // check if we can allow a new client to start downloading form us
     if (::GetTickCount() - m_nLastStartUpload < 1000)
-    {
-        return false;
-    }
-    
+    return false;
     if (uploadinglist.GetCount() < MIN_UP_CLIENTS_ALLOWED)
-    {
-        return true;
-    }
+    return true;
     else if(uploadinglist.GetCount() >= MAX_UP_CLIENTS_ALLOWED)
-    {
-        return false;
-    }
-    
-    uint32 upPerClient = UPLOAD_CLIENT_DATARATE + datarate / 50;
-
+    return false;
+    uint32 upPerClient = UPLOAD_CLIENT_DATARATE + datarate/50;
     if (upPerClient > 10000)
-    {
-        upPerClient = 11000;
-    }
-    
+    upPerClient = 11000;
     //now the final check
-    if (theApp.glob_prefs->GetMaxUpload() == UNLIMITED)
+    if (theApp.dynprefs->Get<long>("limits-upload") == UNLIMITED)
     {
-        if ((uint32)uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
+        if ((uint32) uploadinglist.GetCount() < ((datarate/upPerClient) + 2))
         {
             return true;
         }
@@ -362,20 +338,15 @@ bool CUploadQueue::AcceptNewClient()
     else
     {
         uint16 nMaxSlots = 0;
-        if (theApp.glob_prefs->GetMaxUpload() > 10)
+        if (theApp.dynprefs->Get<long>("limits-upload") > 10)
         {
             nMaxSlots += 2;
-            nMaxSlots += (uint16) ceil((float)((theApp.glob_prefs->GetMaxUpload() - 10) *1024) / upPerClient);
+            nMaxSlots += (uint16) ceil((float)((theApp.dynprefs->Get<long>("limits-upload") - 10) * 1024) / upPerClient);
         }
         else
-        {
-            nMaxSlots = MIN_UP_CLIENTS_ALLOWED;
-        }
-        
-        if ((uint32) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) && uploadinglist.GetCount() <= nMaxSlots)
-        {
-            return true;
-        }
+        nMaxSlots = MIN_UP_CLIENTS_ALLOWED;
+        if ((uint32) uploadinglist.GetCount() < (datarate/UPLOAD_CHECK_CLIENT_DR) &&uploadinglist.GetCount() <= nMaxSlots)
+        return true;
     }
     //nope
     return false;
@@ -383,6 +354,7 @@ bool CUploadQueue::AcceptNewClient()
 
 CUploadQueue::~CUploadQueue()
 {
+    //KillTimer(0,141);
     delete h_timer;
 }
 
@@ -487,7 +459,7 @@ void CUploadQueue::AddClientToQueue(CUpDownClient *client, bool bIgnoreTimelimit
     }
     // done
     // Add clients server to list.
-    if (theApp.glob_prefs->AddServersFromClient())
+    if (theApp.dynprefs->Get<bool>("add-server-client") == true)
     {
         in_addr host;
         host.s_addr = client->GetServerIP();
@@ -585,13 +557,14 @@ void CUploadQueue::RemoveFromWaitingQueue(POSITION pos, bool updatewindow)
     waitinglist.RemoveAt(pos);
     if (todelete->IsBanned())
     todelete->UnBan();
+    //if (updatewindow)
     theApp.xmuledlg->transferwnd->queuelistctrl->RemoveClient(todelete);
     todelete->SetUploadState(US_NONE);
 }
 
 bool CUploadQueue::CheckForTimeOver(CUpDownClient *client)
 {
-    if (theApp.glob_prefs->TransferFullChunks())
+    if (theApp.dynprefs->Get<bool>("transfer-full-chunks") == true)
     {
         // Try to keep the clients from downloading for ever.:
         if (client->GetUpStartTimeDelay() > 3600000)
@@ -652,7 +625,7 @@ void TimerProc()
 {
     // can this actually happen under wxwin?
     if (!theApp.xmuledlg->IsRunning())
-        return;
+    return;
     theApp.uploadqueue->Process();
     theApp.downloadqueue->Process();
     //theApp.clientcredits->Process();
@@ -666,22 +639,15 @@ void TimerProc()
         theApp.clientcredits->Process();
         theApp.serverlist->Process();
         theApp.friendlist->Process();
-        if (theApp.daemon)
-        {
-            if (theApp.lda->ReadCommand())
-            {
-                theApp.ProcessCommand();
-            }
-        }
         if (theApp.serverconnect->IsConnecting() && !theApp.serverconnect->IsSingleConnect())
         theApp.serverconnect->TryAnotherConnectionrequest();
         theApp.xmuledlg->statisticswnd->UpdateConnectionsStatus();
         if (theApp.serverconnect->IsConnecting()) theApp.serverconnect->CheckForTimeout();
         // display graphs
-        if (theApp.glob_prefs->GetTrafficOMeterInterval() > 0)
+        if (theApp.dynprefs->Get<long>("graph-delay") > 0)
         {
             igraph++;
-            if (igraph >= (uint32)(theApp.glob_prefs->GetTrafficOMeterInterval()))
+            if (igraph >= (uint32)(theApp.dynprefs->Get<long>("graph-delay")))
             {
                 igraph = 0;
                 theApp.xmuledlg->statisticswnd->SetCurrentRate((float) theApp.uploadqueue->GetDatarate() /1024, (float) theApp.downloadqueue->GetDatarate() /1024);
@@ -690,10 +656,10 @@ void TimerProc()
         if (theApp.xmuledlg->activewnd == theApp.xmuledlg->statisticswnd)
         {
             // display stats
-            if (theApp.glob_prefs->GetStatsInterval() > 0)
+            if (theApp.dynprefs->Get<long>("tree-delay") > 0)
             {
                 istats++;
-                if (istats >= (uint32)(theApp.glob_prefs->GetStatsInterval()))
+                if (istats >= (uint32)(theApp.dynprefs->Get<long>("tree-delay")))
                 {
                     istats = 0;
                     theApp.xmuledlg->ShowStatistics();
@@ -706,28 +672,21 @@ void TimerProc()
         // 5 seconds
         if (sec >= 5)
         {
+#ifdef _DEBUG
+            if (!AfxCheckMemory()) AfxDebugBreak();
+#endif
             sec = 0;
             theApp.listensocket->Process();
             // Added By Bouc7:
             theApp.OnlineSig();
             theApp.xmuledlg->ShowTransferRate();
-
-            if (theApp.daemon)
-            {
-                theApp.RefreshFiles();
-            }
         }
-
         statsave++;
-        
         if (statsave >= 60)
         {
             statsave = 0;
             CString buffer;
-            char *fullpath = new char[strlen(theApp.glob_prefs->GetAppDir()) + 16];
-            sprintf(fullpath, "%spreferences.ini", theApp.glob_prefs->GetAppDir());
-            CIni ini(fullpath, "xMule");
-            delete[] fullpath;
+            CIni ini(theApp.dynprefs->Get<wxString>("appdir") + wxT("preferences.ini"), "xMule");
             buffer.Format("%llu", theApp.stat_sessionReceivedBytes + theApp.glob_prefs->GetTotalDownloaded());
             ini.WriteString("TotalDownloadedBytes", buffer, "Statistics");
             buffer.Format("%llu", theApp.stat_sessionSentBytes + theApp.glob_prefs->GetTotalUploaded());
@@ -754,29 +713,34 @@ CUpDownClient *CUploadQueue::GetNextClient(CUpDownClient *lastclient)
     return waitinglist.GetAt(pos);
 }
 
-void CUploadQueue::FindSourcesForFileById(CTypedPtrList < CPtrList, CUpDownClient *> *srclist, uchar *filehash)
+void CUploadQueue::FindSourcesForFileById(CTypedPtrList<CPtrList, CUpDownClient *>*srclist, unsigned char * filehash)
 {
     POSITION pos;
     pos = uploadinglist.GetHeadPosition();
+
     while (pos)
     {
-        CUpDownClient *potential = uploadinglist.GetNext(pos);
+        CUpDownClient* potential = uploadinglist.GetNext(pos);
+
         if (md4cmp(potential->GetUploadFileID(), filehash) == 0)
-        srclist->AddTail(potential);
+        {
+            srclist->AddTail(potential);
+        }
     }
+
     pos = waitinglist.GetHeadPosition();
+
     while (pos)
     {
-        CUpDownClient *potential = waitinglist.GetNext(pos);
+        CUpDownClient* potential = waitinglist.GetNext(pos);
+
         if (md4cmp(potential->GetUploadFileID(), filehash) == 0)
-        srclist->AddTail(potential);
+        {
+            srclist->AddTail(potential);
+        }
     }
 }
 
- /*
- * This function adds a file indicated by filehash to suspended_uploads_list
-    */
-
 void CUploadQueue::SuspendUpload(const CFileHash &filehash)
 {
     //Append the filehash to the list.
