@@ -22,7 +22,7 @@
 // Author:      Julian Smart and Guillermo Rodriguez Garcia
 // Modified by:
 // Created:     13/8/99
-// RCS-ID:      $Id: animate.cpp,v 1.22 2004/08/23 05:53:30 HopeSeekr Exp $
+// RCS-ID:      $Id: animate.cpp,v 1.24 2004/10/04 14:58:48 HopeSeekr Exp $
 // Copyright:   (c) Julian Smart and Guillermo Rodriguez Garcia
 // Licence:     wxWindows licence
 ///////////////////////////////////////////////////////////////////////////////
@@ -304,7 +304,7 @@ void wxAnimationPlayer::ClearCache()
 void wxAnimationPlayer::DrawBackground(wxDC &dc, const wxPoint &pos, const wxColour &colour)
 {
     wxASSERT_MSG((m_animation != NULL), "Animation not present in wxAnimationPlayer");
-    wxASSERT_MSG((m_frames.GetCount() != 0), "Animation cache not present in wxAnimationPlayer");
+    wxASSERT_MSG((m_frames.Number() != 0), "Animation cache not present in wxAnimationPlayer");
     // Optimization: if the first frame fills the whole area, and is non-transparent,
     // don't bother drawing the background
     wxBitmap *firstBitmap = (wxBitmap *) m_frames.GetFirst()->GetData();
@@ -354,8 +354,8 @@ void wxAnimationPlayer::SaveBackground(const wxRect &rect)
 void wxAnimationPlayer::DrawFrame(int frame, wxDC &dc, const wxPoint &pos)
 {
     wxASSERT_MSG((m_animation != NULL), "Animation not present in wxAnimationPlayer");
-    wxASSERT_MSG((m_frames.GetCount() != 0), "Animation cache not present in wxAnimationPlayer");
-    wxASSERT_MSG((m_frames.Item(frame) != (wxNode *) NULL), "Image not present in wxAnimationPlayer::DrawFrame");
+    wxASSERT_MSG((m_frames.Number() != 0), "Animation cache not present in wxAnimationPlayer");
+    wxASSERT_MSG((m_frames.Nth(frame) != (wxNode *) NULL), "Image not present in wxAnimationPlayer::DrawFrame");
     wxBitmap *bitmap = (wxBitmap *) m_frames.Item(frame)->GetData();
     wxRect rect = GetFrameRect(frame);
     dc.DrawBitmap( *bitmap, pos.x + rect.x, pos.y + rect.y, (bitmap->GetMask() != NULL));
