@@ -18,11 +18,11 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 #ifdef PRECOMP
-    #include "xmule-headers.h"
+#	include "xmule-headers.h"
+#else
+#	include "CMemFile.h"
 #endif
 
-#include "CMemFile.h"                       // Needed for this Interface's Prototype
-
 CMemFile::CMemFile(unsigned int growBytes)
 {
     fGrowBytes = growBytes;
