@@ -44,7 +44,8 @@ void CLDaemon::Init()
     char *names[]={"command","status","output","server","download","upload"};
     int i;
 
-    wxString PrefDir = getenv("HOME") + wxString("/.xMule/nowindow");
+    wxString PrefDir(getenv("HOME"), *wxConvCurrent);
+    PrefDir += wxT("/.xMule/nowindow");
     if (!wxDirExists(PrefDir))
     {
         mkdir(PrefDir, 0777);
@@ -52,11 +53,11 @@ void CLDaemon::Init()
 
     //
     // LD_COMMAND
-    FName[0] = PrefDir + wxString("/") + wxString (names[0]);
+    FName[0] = PrefDir + wxT("/") + wxString(names[0], *wxConvCurrent);
     if (Ftmp.Open (FName[0],wxFile::write))
 	Ftmp.Close ();
     else
-        printf ("Can't open nowindow/$s file\n",names[0]);
+        printf("Can't open nowindow file (%s)\n", names[0]);
     
     for (i=LD_STATUS;i<LD_NUMBER;++i)
     {
@@ -113,6 +114,7 @@ bool CLDaemon::Read (wxString &Data, int type)
 
     Data=string;
     delete string;
+    return true;
 }
 
 bool CLDaemon::ReadCommand ()
