@@ -33,18 +33,23 @@
 // Author   : Arne Morken
 // Copyright: (C) 2000-2002 MindMatters, www.mindmatters.no
 // Licence  : wxWindows licence
+//
 
 #ifndef _MMMULTIBUTTON_INCLUDED
 #define _MMMULTIBUTTON_INCLUDED
 
+#include "wx/wxprec.h"
+
 #ifdef __BORLANDC__
     #pragma hdrstop
 #endif
 
-#include <wx/event.h>                   // Needed for wxEvent
-#include <wx/button.h>                  // Needed for wxButton
+#ifndef WX_PRECOMP
+    #include "wx/wx.h"
+#endif
 
 // mmMultiButton styles (re-use wxFrame/wxDialog style flags)
+
 #define mmMB_FOCUS         0x0400 // Change bitmap on enter/leave.
 #define mmMB_SELECT        0x0800 // Change bitmap on select.
 #define mmMB_TOGGLE        0x1000 // Change bitmap on toggle.
@@ -178,4 +183,3 @@ class mmMultiButton: public wxWindow
 }; // class mmMultiButton
 
 #endif
-
