@@ -37,48 +37,26 @@
 #ifndef _DYNPREFS_H
 #define _DYNPREFS_H
 
+#include "wxTreeMultiCtrl.h"                // Needed for wxTreeMultiCtrl
+
+#include <list>                             // Needed for std::list
 #include <map>                              // Needed for std::map
 #include <utility>                          // Needed for std::pair
 #include <vector>                           // Needed for std::vector
-#include <ext/slist>                        // Needed for std::slist
 
-#include "wxTreeMultiCtrl.h"                // Needed for wxTreeMultiCtrl
-
-#include <iostream>
 #include <wx/log.h>                         // Needed for wxLogDebug
 
-#if wxCHECK_VERSION(2,5,0)
+#if wxCHECK_VERSION(2, 5, 1)
     #include <wx/xml/xml.h>                 // Needed for wxXmlNode
 #else
     #include <wx/xrc/xml.h>                 // Needed for wxXmlNode
 #endif
 
-using namespace std;
-using __gnu_cxx::slist;
-
 class DynamicPreferences
 {
-private:
-    std::map<const wxString, bool > bools;
-    std::map<const wxString, long > longs;
-    std::map<const wxString, double > doubles;
-    std::map<const wxString, wxString > strings;
-    std::map<const wxString, std::vector<long> > long_list;
-
 public:
-    DynamicPreferences() { }
-
-
-    void RegisterControl(const wxString& preference, const short int type)
-    {
-        controls.push_front(make_pair(preference, type));
-    }
-
     template <typename T>
-    T Get(const wxString& preference)
-    {
-        wxLogDebug(wxString::Format(wxT("Preference datatype is not supported.")));
-    }
+    T Get(const wxString& preference);
 
     void Add(const wxString& preference, bool data);
     void Add(const wxString& preference, double data);
@@ -97,11 +75,11 @@ public:
         T_DIR,
         T_LLONG
     };
-    slist< std::pair<const wxString, const short int > > controls;
 };
 
 class DynamicPreferencesCtrl: public wxTreeMultiCtrl
 {
+friend wxWindow* add_item(wxTreeMultiCtrl* parent, wxXmlNode* node, wxPanel* panel);
 private:
     DynamicPreferences* dynprefs;
 
@@ -109,28 +87,14 @@ public:
     DynamicPreferencesCtrl(const wxString& filename, wxWindow* parent, DynamicPreferences* dp, wxWindowID id = -1, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize);
 
 private:
-    wxString ControlName(const wxString in) const
-    {
-        wxString name(in);
-        name.Remove(0, 1);
-        return name;
-    }
-
-    void OnExpandNode(wxTreeMultiEvent* event);
+    void OnExpandNode(const wxTreeMultiEvent& event);
     void OnCheckBox(wxCommandEvent& event);
     void OnTextChange(wxCommandEvent& event);
-    void OnChangedPrefs(wxEvent* event);
-    void OnBrowse1(wxCommandEvent* event);
-    void OnCombo(wxCommandEvent* event);
-    void OnSlider(wxScrollEvent* event);
+    void OnChangedPrefs(const wxEvent& event);
+    void OnBrowse1(wxCommandEvent& event);
+    void OnCombo(wxCommandEvent& event);
+    void OnSlider(wxScrollEvent& event);
 
-    wxString GetNodeText(wxXmlNode *node) const;
-    wxSize GetNodeSize(wxXmlNode* node) const;
-
-    void parse_xml(wxXmlNode* node, wxTreeMultiItem& current_item);
-    wxWindow* add_item(wxXmlNode* node, wxPanel* panel=NULL);
-
-    wxString* m_string;
     wxXmlDocument* doc;
     DECLARE_EVENT_TABLE()
 };
